==> gs2-cdk-1.0.87.tar.gz: gs2-cdk-1.0.87/src/gs2_cdk/distributor/model/__init__.py <==
# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from .Namespace import Namespace
from .options.NamespaceOptions import NamespaceOptions
from .DistributorModel import DistributorModel
from .options.DistributorModelOptions import DistributorModelOptions
from .BatchRequestPayload import BatchRequestPayload
from .options.BatchRequestPayloadOptions import BatchRequestPayloadOptions
from .enum.BatchRequestPayloadService import BatchRequestPayloadService
from .BatchResultPayload import BatchResultPayload
from .options.BatchResultPayloadOptions import BatchResultPayloadOptions
from .AcquireActionResult import AcquireActionResult
from .options.AcquireActionResultOptions import AcquireActionResultOptions
from .ConsumeActionResult import ConsumeActionResult
from .options.ConsumeActionResultOptions import ConsumeActionResultOptions
from .VerifyActionResult import VerifyActionResult
from .options.VerifyActionResultOptions import VerifyActionResultOptions
from .DistributeResource import DistributeResource
from .options.DistributeResourceOptions import DistributeResourceOptions
from .CurrentMasterData import CurrentMasterData

==> gs2-cdk-1.0.109.tar.gz: gs2-cdk-1.0.109/src/gs2_cdk/distributor/model/__init__.py <==
# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from .Namespace import Namespace
from .options.NamespaceOptions import NamespaceOptions
from .DistributorModel import DistributorModel
from .options.DistributorModelOptions import DistributorModelOptions
from .BatchRequestPayload import BatchRequestPayload
from .options.BatchRequestPayloadOptions import BatchRequestPayloadOptions
from .enums.BatchRequestPayloadService import BatchRequestPayloadService
from .BatchResultPayload import BatchResultPayload
from .options.BatchResultPayloadOptions import BatchResultPayloadOptions
from .AcquireActionResult import AcquireActionResult
from .options.AcquireActionResultOptions import AcquireActionResultOptions
from .ConsumeActionResult import ConsumeActionResult
from .options.ConsumeActionResultOptions import ConsumeActionResultOptions
from .VerifyActionResult import VerifyActionResult
from .options.VerifyActionResultOptions import VerifyActionResultOptions
from .DistributeResource import DistributeResource
from .options.DistributeResourceOptions import DistributeResourceOptions
from .CurrentMasterData import CurrentMasterData
